aboutsummaryrefslogtreecommitdiffstats
path: root/CAN-binder/low-can-binding/can/can-bus-dev.cpp
diff options
context:
space:
mode:
authorRomain Forlot <romain.forlot@iot.bzh>2017-04-25 19:58:08 +0200
committerRomain Forlot <romain.forlot@iot.bzh>2017-04-27 00:53:49 +0200
commit45dd042f924236be04d4e4292de111f80a004060 (patch)
treeffaa576e3d36ee81d708aa96ec5ea14a73b8f18d /CAN-binder/low-can-binding/can/can-bus-dev.cpp
parentc1dc2bdc685cff74ceef67e9658e1b193b01b67f (diff)
Renaming confusing member "address_" to "index_"
Change-Id: I0ec6d74e9adb791f8bef44f76c74be8365cdf037 Signed-off-by: Romain Forlot <romain.forlot@iot.bzh>
Diffstat (limited to 'CAN-binder/low-can-binding/can/can-bus-dev.cpp')
-rw-r--r--CAN-binder/low-can-binding/can/can-bus-dev.cpp11
1 files changed, 6 insertions, 5 deletions
diff --git a/CAN-binder/low-can-binding/can/can-bus-dev.cpp b/CAN-binder/low-can-binding/can/can-bus-dev.cpp
index 6b8d914..1aaefc9 100644
--- a/CAN-binder/low-can-binding/can/can-bus-dev.cpp
+++ b/CAN-binder/low-can-binding/can/can-bus-dev.cpp
@@ -33,9 +33,9 @@
/// @brief Class constructor
///
/// @param[in] dev_name - String representing the device name into the linux /dev tree
-/// @param[in] address - integer identifier of the bus, set using init_can_dev from can_bus_t.
-can_bus_dev_t::can_bus_dev_t(const std::string& dev_name, int32_t address)
- : device_name_{dev_name}, address_{address}
+/// @param[in] index - integer identifier of the bus, set using init_can_dev from can_bus_t.
+can_bus_dev_t::can_bus_dev_t(const std::string& dev_name, int index)
+ : device_name_{dev_name}, index_{index}
{}
std::string can_bus_dev_t::get_device_name() const
@@ -43,9 +43,10 @@ std::string can_bus_dev_t::get_device_name() const
return device_name_;
}
-uint32_t can_bus_dev_t::get_address() const
+int can_bus_dev_t::get_index() const
{
- return address_;
+ return index_;
+}
}
/// @brief Open the can socket and returning it